@@ -436,21 +436,25 @@ var hierarchy =
     [ "juce::SingleThreadedReferenceCountedObject", "classjuce_1_1SingleThreadedReferenceCountedObject.html", null ],
     [ "juce::SingletonHolder< Type, MutexType, onlyCreateOncePerRun >", "structjuce_1_1SingletonHolder.html", null ],
     [ "juce::TypeHelpers::SmallestFloatType< Type >", "namespacejuce_1_1TypeHelpers.html#structjuce_1_1TypeHelpers_1_1SmallestFloatType", null ],
-    [ "juce::SmoothedValueBase< SmoothedValueType >", "classjuce_1_1SmoothedValueBase.html", [
-      [ "juce::SmoothedValue< float >", "classjuce_1_1SmoothedValue.html", null ],
-      [ "juce::SmoothedValue< Type >", "classjuce_1_1SmoothedValue.html", null ],
-      [ "juce::SmoothedValue< NumericType >", "classjuce_1_1SmoothedValue.html", null ],
-      [ "juce::dsp::LogRampedValue< float >", "classjuce_1_1dsp_1_1LogRampedValue.html", null ],
-      [ "juce::SmoothedValue< FloatType, SmoothingType >", "classjuce_1_1SmoothedValue.html", null ]
+    [ "juce::SmoothedValueBase< SmoothedValueType >", "classjuce_1_1SmoothedValueBase.html", null ],
+    [ "juce::SmoothedValueBase< LogRampedValue< float > >", "classjuce_1_1SmoothedValueBase.html", [
+      [ "juce::dsp::LogRampedValue< float >", "classjuce_1_1dsp_1_1LogRampedValue.html", null ]
     ] ],
-    [ "juce::SmoothedValueBase< LogRampedValue< float > >", "classjuce_1_1SmoothedValueBase.html", null ],
     [ "juce::SmoothedValueBase< LogRampedValue< FloatType > >", "classjuce_1_1SmoothedValueBase.html", [
       [ "juce::dsp::LogRampedValue< FloatType >", "classjuce_1_1dsp_1_1LogRampedValue.html", null ]
     ] ],
-    [ "juce::SmoothedValueBase< SmoothedValue< float, ValueSmoothingTypes::Linear > >", "classjuce_1_1SmoothedValueBase.html", null ],
-    [ "juce::SmoothedValueBase< SmoothedValue< FloatType, ValueSmoothingTypes::Linear > >", "classjuce_1_1SmoothedValueBase.html", null ],
-    [ "juce::SmoothedValueBase< SmoothedValue< NumericType, ValueSmoothingTypes::Linear > >", "classjuce_1_1SmoothedValueBase.html", null ],
-    [ "juce::SmoothedValueBase< SmoothedValue< Type, ValueSmoothingTypes::Linear > >", "classjuce_1_1SmoothedValueBase.html", null ],
+    [ "juce::SmoothedValueBase< SmoothedValue< float, ValueSmoothingTypes::Linear > >", "classjuce_1_1SmoothedValueBase.html", [
+      [ "juce::SmoothedValue< float >", "classjuce_1_1SmoothedValue.html", null ]
+    ] ],
+    [ "juce::SmoothedValueBase< SmoothedValue< FloatType, ValueSmoothingTypes::Linear > >", "classjuce_1_1SmoothedValueBase.html", [
+      [ "juce::SmoothedValue< FloatType, SmoothingType >", "classjuce_1_1SmoothedValue.html", null ]
+    ] ],
+    [ "juce::SmoothedValueBase< SmoothedValue< NumericType, ValueSmoothingTypes::Linear > >", "classjuce_1_1SmoothedValueBase.html", [
+      [ "juce::SmoothedValue< NumericType >", "classjuce_1_1SmoothedValue.html", null ]
+    ] ],
+    [ "juce::SmoothedValueBase< SmoothedValue< Type, ValueSmoothingTypes::Linear > >", "classjuce_1_1SmoothedValueBase.html", [
+      [ "juce::SmoothedValue< Type >", "classjuce_1_1SmoothedValue.html", null ]
+    ] ],
     [ "juce::SortedSet< ElementType, TypeOfCriticalSectionToUse >", "classjuce_1_1SortedSet.html", null ],
     [ "juce::SortedSet< juce::ActionListener * >", "classjuce_1_1SortedSet.html", null ],
     [ "juce::SortedSet< juce::Value * >", "classjuce_1_1SortedSet.html", null ],
