@@ -51,24 +51,24 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "annotated.html",
-"classjuce_1_1AudioChannelSet.html#a7011c4aff026f4b48d1a545aebc03ac1a8442bfdc68c5dbf4e1a6693ff9b61896",
-"classjuce_1_1AudioProcessLoadMeasurer.html",
-"classjuce_1_1CharPointer__UTF16.html#a6422c90ef9c521a55eba6f303e30e6a6",
-"classjuce_1_1File.html#a01aa22f7ebb9b06840c2118a5e99964a",
-"classjuce_1_1IIRCoefficients.html",
-"classjuce_1_1MPEInstrument.html#a41a654610f46359202f9ecf3ee0cbbf8",
-"classjuce_1_1MidiBuffer.html#ade4e9d5b4ca396e94c03d3370972b77c",
-"classjuce_1_1NamedPipe.html#a9af215d2dd492dc72d7027e029bc74b3",
-"classjuce_1_1ReadWriteLock.html#a9668721cf0be4b64da52f71ecba9820d",
-"classjuce_1_1SortedSet.html#aadc4aee7c8854ead9f7b9276189dc309",
-"classjuce_1_1StringArray.html#aac7ba501945605961549f6fee1286625",
-"classjuce_1_1ThreadPoolJob.html#aff1ded5a73f7e20a65fad92bb62f7c53",
-"classjuce_1_1ValueTree.html#a8e50d4669c64ea66bdf406cd160884be",
-"classjuce_1_1dsp_1_1AudioBlock.html#a4ae2c15be9dc8d00bf3b5ebcc7e49a80",
-"classjuce_1_1var.html#a5d205a32b1448993c1525ed4280759f7",
-"juce__ConsoleApplication_8cpp_source.html",
-"juce__TargetPlatform_8h_source.html",
-"structjuce_1_1MPESynthesiserBase.html#ac43f7a6087ee7b92798d3d4a3ba21241"
+"classjuce_1_1AudioChannelSet.html#a7011c4aff026f4b48d1a545aebc03ac1a85046911e0b8be3e9b6c03c334c4f0f2",
+"classjuce_1_1AudioProcessLoadMeasurer.html#a0e9d2e2be5168a8ce8438dd82b4a2efc",
+"classjuce_1_1CharPointer__UTF16.html#a7e91be1fb14a44b599b95359cc7432b9",
+"classjuce_1_1File.html#a0862e82477e71f87767d9e179ea8755b",
+"classjuce_1_1IIRCoefficients.html#a2fb0d935a2eca3302963b2eddbd49443",
+"classjuce_1_1MPEInstrument.html#a4d063e2629616fa2e23d8c025939dd0b",
+"classjuce_1_1MidiBuffer.html#af964706592abb799c9fef1c885cf5921",
+"classjuce_1_1NamedPipe.html#aa37c72d4cee557d346998e44522a3f64",
+"classjuce_1_1ReferenceCountedArray.html",
+"classjuce_1_1SortedSet.html#abc1d6a4e9bde78b644b039c3bea9b7eb",
+"classjuce_1_1StringArray.html#ab6e2dc223d4bfb654d75670d0b4aebcc",
+"classjuce_1_1Thread_1_1Listener.html",
+"classjuce_1_1ValueTree.html#a98d6f83140f913101a059e611b7dfade",
+"classjuce_1_1dsp_1_1AudioBlock.html#a55479b945d7a46f0e11ed279800628f0",
+"classjuce_1_1var.html#aa0baad0471288b84ca67bd4f8dd2c56f",
+"juce__CoreAudioFormat_8cpp_source.html",
+"juce__ThreadLocalValue_8h_source.html",
+"structjuce_1_1MPESynthesiserBase.html#af6ba9ae35f0a3d65f1cafa0c6acd646a"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
