@@ -1,8 +1,5 @@
 var NAVTREEINDEX13 =
 {
-"classjuce_1_1ValueTree.html#a8e50d4669c64ea66bdf406cd160884be":[2,0,0,218,36],
-"classjuce_1_1ValueTree.html#a8e9bfd167e23febb57d7e2d0e289e987":[2,0,0,218,45],
-"classjuce_1_1ValueTree.html#a91ef4df4f2007e83b137a65b5ea59124":[2,0,0,218,9],
 "classjuce_1_1ValueTree.html#a98d6f83140f913101a059e611b7dfade":[2,0,0,218,10],
 "classjuce_1_1ValueTree.html#a9fbe22cceb6b7e4d8a5c9d86dd89ef03":[2,0,0,218,35],
 "classjuce_1_1ValueTree.html#aa06fd185c74db487c9d32466fa4f75fa":[2,0,0,218,42],
@@ -83,17 +80,15 @@ var NAVTREEINDEX13 =
 "classjuce_1_1WavAudioFormat.html#a2f774638a06a8404b2b1f8be2b5db03b":[2,0,0,224,2],
 "classjuce_1_1WavAudioFormat.html#a398ddc78d5c3ece5ed6d50a20c508339":[2,0,0,224,5],
 "classjuce_1_1WavAudioFormat.html#a4be74b6cbf380fb0c7183342b2fb9bbb":[2,0,0,224,3],
-"classjuce_1_1WavAudioFormat.html#a4fdbbb644f01a4286ae4496bcf8687dd":[2,0,0,224,9],
 "classjuce_1_1WavAudioFormat.html#a844d328af30501c8d93300961c276254":[2,0,0,224,4],
-"classjuce_1_1WavAudioFormat.html#a8521da729af3b5835a78e6c3ac044f1f":[2,0,0,224,12],
-"classjuce_1_1WavAudioFormat.html#a95602585351f87baea7bd72c0a579605":[2,0,0,224,13],
+"classjuce_1_1WavAudioFormat.html#a8521da729af3b5835a78e6c3ac044f1f":[2,0,0,224,10],
+"classjuce_1_1WavAudioFormat.html#a95602585351f87baea7bd72c0a579605":[2,0,0,224,11],
 "classjuce_1_1WavAudioFormat.html#a97d4fb48b04c8c54de950f391314f648":[2,0,0,224,1],
-"classjuce_1_1WavAudioFormat.html#aa4f2864fc806f183eda33efe9e30f03c":[2,0,0,224,8],
-"classjuce_1_1WavAudioFormat.html#ab24b6ffb551bc6cb2543e111d5650b20":[2,0,0,224,11],
-"classjuce_1_1WavAudioFormat.html#abc557f6f759552ec6b4302629739a788":[2,0,0,224,6],
-"classjuce_1_1WavAudioFormat.html#ac04a377d9a1bcf2f19ff65fb8f7d1f61":[2,0,0,224,10],
+"classjuce_1_1WavAudioFormat.html#aa4f2864fc806f183eda33efe9e30f03c":[2,0,0,224,7],
+"classjuce_1_1WavAudioFormat.html#ab24b6ffb551bc6cb2543e111d5650b20":[2,0,0,224,9],
+"classjuce_1_1WavAudioFormat.html#ac04a377d9a1bcf2f19ff65fb8f7d1f61":[2,0,0,224,8],
 "classjuce_1_1WavAudioFormat.html#af6753c1766e9d5096c84347ff017dc88":[2,0,0,224,0],
-"classjuce_1_1WavAudioFormat.html#afccb5c91a942c07733010634c5008634":[2,0,0,224,7],
+"classjuce_1_1WavAudioFormat.html#afccb5c91a942c07733010634c5008634":[2,0,0,224,6],
 "classjuce_1_1WeakReference.html":[2,0,0,225],
 "classjuce_1_1WeakReference.html#a0aba18efc30a636d9f19f9b1d9e2ec95":[2,0,0,225,11],
 "classjuce_1_1WeakReference.html#a1994b9d89ff037aa2f5bcc147af95d24":[2,0,0,225,8],
@@ -249,5 +244,10 @@ var NAVTREEINDEX13 =
 "classjuce_1_1dsp_1_1AudioBlock.html#a3ecb39e005a43e3ebb45ebced34aa107":[2,0,0,0,3,18],
 "classjuce_1_1dsp_1_1AudioBlock.html#a40d870e56be54d3fe1d5a1442dcca202":[2,0,0,0,3,39],
 "classjuce_1_1dsp_1_1AudioBlock.html#a4440322329bc6ce038843dc576c0aa06":[2,0,0,0,3,33],
-"classjuce_1_1dsp_1_1AudioBlock.html#a46831bc88038f2d8ffadd9061d392741":[2,0,0,0,3,16]
+"classjuce_1_1dsp_1_1AudioBlock.html#a46831bc88038f2d8ffadd9061d392741":[2,0,0,0,3,16],
+"classjuce_1_1dsp_1_1AudioBlock.html#a4ae2c15be9dc8d00bf3b5ebcc7e49a80":[2,0,0,0,3,17],
+"classjuce_1_1dsp_1_1AudioBlock.html#a4c4166dad5077aff9a25b05c2a784e19":[2,0,0,0,3,29],
+"classjuce_1_1dsp_1_1AudioBlock.html#a4d53fd59a25802f02632c7dbc144c3f1":[2,0,0,0,3,35],
+"classjuce_1_1dsp_1_1AudioBlock.html#a4e110ed6a97143ed800ffe2bf724f3e5":[2,0,0,0,3,31],
+"classjuce_1_1dsp_1_1AudioBlock.html#a52b391998ac15a6d5aa6dc0ff6d21082":[2,0,0,0,3,40]
 };
