@@ -1,10 +1,5 @@
 var NAVTREEINDEX14 =
 {
-"classjuce_1_1dsp_1_1AudioBlock.html#a4ae2c15be9dc8d00bf3b5ebcc7e49a80":[2,0,0,0,3,17],
-"classjuce_1_1dsp_1_1AudioBlock.html#a4c4166dad5077aff9a25b05c2a784e19":[2,0,0,0,3,29],
-"classjuce_1_1dsp_1_1AudioBlock.html#a4d53fd59a25802f02632c7dbc144c3f1":[2,0,0,0,3,35],
-"classjuce_1_1dsp_1_1AudioBlock.html#a4e110ed6a97143ed800ffe2bf724f3e5":[2,0,0,0,3,31],
-"classjuce_1_1dsp_1_1AudioBlock.html#a52b391998ac15a6d5aa6dc0ff6d21082":[2,0,0,0,3,40],
 "classjuce_1_1dsp_1_1AudioBlock.html#a55479b945d7a46f0e11ed279800628f0":[2,0,0,0,3,5],
 "classjuce_1_1dsp_1_1AudioBlock.html#a619c7b0ec9ebed564892a9d502e07145":[2,0,0,0,3,27],
 "classjuce_1_1dsp_1_1AudioBlock.html#a61c239322781c08f131e674990d68cc6":[2,0,0,0,3,7],
@@ -249,5 +244,10 @@ var NAVTREEINDEX14 =
 "classjuce_1_1var.html#a49c1ab09a21199e36f054ebd9b3a4707":[2,0,0,221,2],
 "classjuce_1_1var.html#a4e19664ff13681974e4666ea0887963a":[2,0,0,221,13],
 "classjuce_1_1var.html#a4edbff092eacc25ac1336cef28f05ee0":[2,0,0,221,19],
-"classjuce_1_1var.html#a509a018cb9166afacb22f9f12d1cfba9":[2,0,0,221,25]
+"classjuce_1_1var.html#a509a018cb9166afacb22f9f12d1cfba9":[2,0,0,221,25],
+"classjuce_1_1var.html#a5d205a32b1448993c1525ed4280759f7":[2,0,0,221,23],
+"classjuce_1_1var.html#a5df89a3f68d34a7a0a6eee6e47329123":[2,0,0,221,15],
+"classjuce_1_1var.html#a6bcd41a637830491f657af9194500d35":[2,0,0,221,17],
+"classjuce_1_1var.html#a85fb75a07bbc6dbee349f74f16b9453b":[2,0,0,221,8],
+"classjuce_1_1var.html#a9a038edc050c083632bfe8d83013fb71":[2,0,0,221,3]
 };
