@@ -1,10 +1,5 @@
 var NAVTREEINDEX15 =
 {
-"classjuce_1_1var.html#a5d205a32b1448993c1525ed4280759f7":[2,0,0,221,23],
-"classjuce_1_1var.html#a5df89a3f68d34a7a0a6eee6e47329123":[2,0,0,221,15],
-"classjuce_1_1var.html#a6bcd41a637830491f657af9194500d35":[2,0,0,221,17],
-"classjuce_1_1var.html#a85fb75a07bbc6dbee349f74f16b9453b":[2,0,0,221,8],
-"classjuce_1_1var.html#a9a038edc050c083632bfe8d83013fb71":[2,0,0,221,3],
 "classjuce_1_1var.html#aa0baad0471288b84ca67bd4f8dd2c56f":[2,0,0,221,11],
 "classjuce_1_1var.html#ab7f42c7923ae3f234e291c3f13ea77a0":[2,0,0,221,12],
 "classjuce_1_1var.html#ab81529a34a9b710354cfa59fb3aa9bc5":[2,0,0,221,27],
@@ -16,62 +11,62 @@ var NAVTREEINDEX15 =
 "classjuce_1_1var.html#ae9ee28970e3a0d55bf489ed4e1b6f8c6":[2,0,0,221,18],
 "classjuce_1_1var.html#aedc4bba756c60d5a034ea2cff620d1a6":[2,0,0,221,10],
 "classjuce_1_1var.html#af8c036ab30cbef3525bbb6f369babd19":[2,0,0,221,14],
-"dir_03c849e2a2595e86f04c75076fd2ac2a.html":[3,0,0,0,0,4],
-"dir_0ce01a4c55fc3ce339c8d6af1eabb7e4.html":[3,0,0,0,0,5,5],
-"dir_0dee5ea6ddf01c74f7d71032b95a6c77.html":[3,0,0,0,0,6,3],
-"dir_0f9f6443cf52e882f172317cb51ca0cd.html":[3,0,0,0,0,1,0],
-"dir_10317e0379ad38581703a427b9cbc41c.html":[3,0,0,0,0,3,10],
-"dir_1047a26977ef0910f8a9aacb85e01df5.html":[3,0,0,0,0,3,6],
-"dir_11a4fb938367959328c552daef8167eb.html":[3,0,0,0,0,5,0],
-"dir_1667c5a2a236bca25538468ef076824b.html":[3,0,0,0,0,3,13],
-"dir_17e6f37fde833f7a72c82a2959288f3a.html":[3,0,0,0,0,3,7],
-"dir_1dae440faec3333c682ac703e837415e.html":[3,0,0,0,0,6],
-"dir_25ba26af2915c5bfa66ed640eca4d9f0.html":[3,0,0,0,0,3,9],
-"dir_26b787f87b44c067da5fdf35e4b36d24.html":[3,0,0,0,0,3,8],
-"dir_286d3ee14bb680fa52ba7a5611800dd0.html":[3,0,0,0,0,0,3],
-"dir_293b55f733d393d919e2c5170d886231.html":[3,0,0,0,0,1],
-"dir_30869642e2a2b0a03fec386d36574069.html":[3,0,0,0,0,6,0],
-"dir_3669a268ba3dbda0cecc0d37cb728712.html":[3,0,0,0,0,0,1],
-"dir_38ddd1112e5f4d2e7d4a97635507d329.html":[3,0,0,0,0,0,2],
-"dir_3a4ff69ea9a2988b94e3e5693bef1c38.html":[3,0,0,0,0,0,0],
-"dir_40dc2aec00dfabc382bfdb69ed5255bd.html":[3,0,0,0,0,3,0],
-"dir_4ac6b55daf36a0337ecfb90c1d2e31f3.html":[3,0,0,0,0,5,3],
-"dir_4b45237f3556e49d017c02c699178391.html":[3,0,0,0,0,0],
-"dir_4b7404fa81834e13f7cec2a28e509044.html":[3,0,0,0,0,1,1],
-"dir_4d07441a9fc4be4bf057b74d88d24ce8.html":[3,0,0,0,0,5,1],
-"dir_4f643913129a34a455a02e535b237421.html":[3,0,0,0,0,4,2],
-"dir_54de26ddcc71b816fee66ccab0833851.html":[3,0,0,0,0,3,1],
-"dir_56d93452b44c5b7e32b137cc091966fb.html":[3,0,0,0,0,3],
-"dir_576780766753afb6a0636850818e0922.html":[3,0,0,0,0,4,0],
-"dir_59b746f1206700b2f0396e1e17a31aaa.html":[3,0,0,0,0,3,2],
-"dir_5ff31f5251cc603a2f6495326114c1a3.html":[3,0,0,0,0,6,2],
-"dir_61847a9788537a694519be344b5e487a.html":[3,0,0,0,0,0,5],
-"dir_61cf6e50797054c09d25a0587e26347c.html":[3,0,0,0,0,3,15],
-"dir_6309744349090c9b2e2779b1b378a67f.html":[3,0,0,0,0,3,4],
-"dir_675d24b7e84838080e327be153292e1b.html":[3,0,0,0,0,5,4],
-"dir_75e9203eb49e75215d982c48860e66d3.html":[3,0,0,0,0,3,14],
-"dir_7ce811a6e011f49442a9d61e81ea5b73.html":[3,0,0,0,0,6,1],
-"dir_7dd2d81d21b6b8976d294a393f17cabc.html":[3,0,0,0,0,2,2],
-"dir_85b15f8e30765e737a8c1ecadf06c758.html":[3,0,0,0,0,0,4],
-"dir_885c49fe0df29414e2c37b38ae61ee2b.html":[3,0,0,0,0,2,0],
-"dir_885c64c19a36f7bb97fab6c48a2cc275.html":[3,0,0,0],
-"dir_9440c2b78a7b1e7bdf8dd9fb4bf026f7.html":[3,0,0,0,0,0,7],
-"dir_a435a203385cf70c63a7d971b5d89486.html":[3,0,0,0,0,2,1],
-"dir_a6a5dcb36b16b9398b621bdeae65039d.html":[3,0,0,0,0,5,2],
-"dir_a9928d69f8182fd332cca57e35805d7c.html":[3,0,0,0,0,0,6],
-"dir_abcc1a2b85be4fb7241bd498dc5ed61b.html":[3,0,0],
-"dir_d704e4622bb077866416b39ec6799618.html":[3,0,0,0,0,3,3],
-"dir_e233e2c131174f34854d4175b7d25a51.html":[3,0,0,0,0,4,1],
-"dir_e48a37890d1f50af4a0c65221718dbc3.html":[3,0,0,0,0,5],
-"dir_e93d838a776d3ce2d5a2f9105553f2cc.html":[3,0,0,0,0,1,2],
-"dir_f484da6757d74d2dcecf8f0e44e0edcc.html":[3,0,0,0,0,3,5],
-"dir_f5141b48c413cc4d183fb3911a026df2.html":[3,0,0,0,0,3,11],
-"dir_f53cf536606c2ecc3b00e34879678cbe.html":[3,0,0,0,0,2],
-"dir_f55ae605621efb555b16f54091514afd.html":[3,0,0,0,0,3,12],
-"dir_fc4f36d37e0302ce55112a2e015a9be1.html":[3,0,0,0,0],
+"dir_13566d2a212b05888d89427f38738f0c.html":[3,0,0,0,0,3,11],
+"dir_1684bb35222975770f0e120704dc52e8.html":[3,0,0,0,0,5,5],
+"dir_1a0ea15018a7496ad6b8225588db552f.html":[3,0,0,0,0,3,4],
+"dir_1d652608c527c9f21dbc21f951a8740e.html":[3,0,0,0,0,2,0],
+"dir_232a00d6d36324eeae0c308535c576b1.html":[3,0,0,0,0,0],
+"dir_25378a0a85d0983921bff2cc32cf58fd.html":[3,0,0,0,0,1,0],
+"dir_27959e4176d0858f63c80dd5b37bdbc7.html":[3,0,0,0,0,3],
+"dir_353cab7bf2aba880de27a05b3e2102ba.html":[3,0,0,0,0,3,6],
+"dir_38829b3e4833c698c95f902492e12e27.html":[3,0,0,0,0,5,2],
+"dir_47cc7a85ba86def2bd918a1a27782b06.html":[3,0,0,0],
+"dir_542d6ec7badc449b38716e73f9b6669c.html":[3,0,0,0,0,3,14],
+"dir_5870092ee92409b29f2939a22cd9c7ae.html":[3,0,0,0,0,3,0],
+"dir_58cdf8ce06b4a832fa470e3e339246f3.html":[3,0,0,0,0,0,1],
+"dir_5d0b6fc385a022dde15eea9a061c5bcc.html":[3,0,0,0,0,0,3],
+"dir_5d176bc03c1e43f7c32158b0e66e9254.html":[3,0,0,0,0,0,2],
+"dir_7e5ce4b532c3f0a75dc09f6915f25b17.html":[3,0,0,0,0,6,2],
+"dir_7e8dc550d8b87b0c26bce2c747a5006c.html":[3,0,0,0,0,3,10],
+"dir_7ef7035cb577c663c7f2cdbe65abbe01.html":[3,0,0,0,0,5,4],
+"dir_87f0fb71ecfe49d5e703ba70e7b81a5a.html":[3,0,0,0,0,3,2],
+"dir_909c0ae122fa96c34253e6293e886888.html":[3,0,0,0,0,0,7],
+"dir_91331527a00032bc747e68fbf4722a06.html":[3,0,0,0,0,3,5],
+"dir_949b4bf041ee2b85eabbb899490d487f.html":[3,0,0,0,0,3,3],
+"dir_951a715897c2e0e9b46716c8b3dfccc6.html":[3,0,0,0,0,6,3],
+"dir_966646c9167d80d95215fe0c9eb86f7e.html":[3,0,0,0,0,5,0],
+"dir_9a99a2f703d8566d0ce69fe213f5dfd5.html":[3,0,0,0,0],
+"dir_9bd4d1f04019ce47f3246058f89c50d2.html":[3,0,0,0,0,2],
+"dir_9f28eb5dd8f8a0c2e797c65a2398aa32.html":[3,0,0,0,0,5,1],
+"dir_a380e146b576377e8436e22ec3045c63.html":[3,0,0,0,0,4,1],
+"dir_a834646a1d418edbb2e93df40fd70cb2.html":[3,0,0,0,0,3,1],
+"dir_aa0ca2603eb893d1c1bdf75dbf4966d7.html":[3,0,0,0,0,4,0],
+"dir_ab331f62a9ac9a1cdf3a55d4aaf00fc8.html":[3,0,0,0,0,5],
+"dir_b996cd4f216276640c86f6a8c7b59345.html":[3,0,0],
+"dir_bbc2014c6e6d98cce63a4141c8476c64.html":[3,0,0,0,0,3,13],
+"dir_bebf2693e641c26e34d501e2a6827422.html":[3,0,0,0,0,3,7],
+"dir_c25338d99edbb73a127fd18ee3e970a8.html":[3,0,0,0,0,2,1],
+"dir_c5a46a86e6410f682a44222a4e21da3d.html":[3,0,0,0,0,6],
+"dir_cb99f78002c81a823223247fc122bf28.html":[3,0,0,0,0,0,5],
+"dir_cbbe1fe6712304fc0a6bc15e6920b89f.html":[3,0,0,0,0,1],
+"dir_ccd5c27abc670d4a67bb6776d55541e1.html":[3,0,0,0,0,0,6],
+"dir_cdbd9ed41d22e11f06700a22f731e8df.html":[3,0,0,0,0,2,2],
+"dir_cf3d466098ee8565bf365b5c779978ea.html":[3,0,0,0,0,3,15],
+"dir_d1cb3f6267d55d21d876f107ac13c51b.html":[3,0,0,0,0,3,12],
+"dir_db0754fd0f2ebb1a29c21b9786910650.html":[3,0,0,0,0,0,0],
+"dir_de93eae0475176afbe0d6d65441773fc.html":[3,0,0,0,0,3,9],
+"dir_e789854a4308a0f50d63805f28067aaf.html":[3,0,0,0,0,1,2],
+"dir_ebec748adca8d108128be925f8b5319f.html":[3,0,0,0,0,5,3],
+"dir_ecec25957d6fb09cbf18b20c9771914a.html":[3,0,0,0,0,6,1],
+"dir_f7864c6597cb102351e0c6e3978e0a45.html":[3,0,0,0,0,1,1],
+"dir_f79d6108e86415a236efd5f4a89f411d.html":[3,0,0,0,0,4],
+"dir_fb5b6694c63df4308ec6388dc0a7a058.html":[3,0,0,0,0,3,8],
+"dir_fd07825313940f584edf3b80be897d3f.html":[3,0,0,0,0,0,4],
+"dir_fd9b71067bca2e2ffd019b6278094d60.html":[3,0,0,0,0,4,2],
+"dir_fe006361007df4288409ed48e8dc5eff.html":[3,0,0,0,0,6,0],
 "files.html":[3,0],
-"functions.html":[2,3,0,0],
 "functions.html":[2,3,0],
+"functions.html":[2,3,0,0],
 "functions_b.html":[2,3,0,1],
 "functions_c.html":[2,3,0,2],
 "functions_d.html":[2,3,0,3],
@@ -249,5 +244,10 @@ var NAVTREEINDEX15 =
 "juce__ChildProcess_8cpp_source.html":[3,0,0,0,0,3,11,0],
 "juce__ChildProcess_8h_source.html":[3,0,0,0,0,3,11,1],
 "juce__ConnectedChildProcess_8cpp_source.html":[3,0,0,0,0,6,1,0],
-"juce__ConnectedChildProcess_8h_source.html":[3,0,0,0,0,6,1,1]
+"juce__ConnectedChildProcess_8h_source.html":[3,0,0,0,0,6,1,1],
+"juce__ConsoleApplication_8cpp_source.html":[3,0,0,0,0,3,6,0],
+"juce__ConsoleApplication_8h_source.html":[3,0,0,0,0,3,6,1],
+"juce__ContainerDeletePolicy_8h_source.html":[3,0,0,0,0,3,5,2],
+"juce__Convolution_8cpp_source.html":[3,0,0,0,0,5,2,0],
+"juce__Convolution_8h_source.html":[3,0,0,0,0,5,2,1]
 };
