@@ -1,6 +1,5 @@
 var NAVTREEINDEX2 =
 {
-"classjuce_1_1AudioProcessLoadMeasurer.html":[2,0,0,29],
 "classjuce_1_1AudioProcessLoadMeasurer.html#a0e9d2e2be5168a8ce8438dd82b4a2efc":[2,0,0,29,1],
 "classjuce_1_1AudioProcessLoadMeasurer.html#a2a9a340b4255a16b443070330b3ec3f3":[2,0,0,29,2],
 "classjuce_1_1AudioProcessLoadMeasurer.html#a4b5e7a6a434d59ed9b139ec362ff4b6c":[2,0,0,29,5],
@@ -28,10 +27,9 @@ var NAVTREEINDEX2 =
 "classjuce_1_1AudioSubsectionReader.html":[2,0,0,33],
 "classjuce_1_1AudioSubsectionReader.html#a04b18267bd3f00de866594b559b25339":[2,0,0,33,0],
 "classjuce_1_1AudioSubsectionReader.html#a15ef0f428cc519bef55e5580e6e104d7":[2,0,0,33,1],
-"classjuce_1_1AudioSubsectionReader.html#a4cea22cc17c300bbba75c3260fefd4d9":[2,0,0,33,4],
+"classjuce_1_1AudioSubsectionReader.html#a4cea22cc17c300bbba75c3260fefd4d9":[2,0,0,33,3],
 "classjuce_1_1AudioSubsectionReader.html#aa271efceec031566548af063dd372ca3":[2,0,0,33,2],
-"classjuce_1_1AudioSubsectionReader.html#ad0159b2b47a152f37d488320ed591a01":[2,0,0,33,3],
-"classjuce_1_1AudioSubsectionReader.html#ae4e44c909d60677877c333513cb2df61":[2,0,0,33,5],
+"classjuce_1_1AudioSubsectionReader.html#ae4e44c909d60677877c333513cb2df61":[2,0,0,33,4],
 "classjuce_1_1AudioTransportSource.html":[2,0,0,34],
 "classjuce_1_1AudioTransportSource.html#a03938aadcc3c6f250b98c54184595f60":[2,0,0,34,18],
 "classjuce_1_1AudioTransportSource.html#a03d4a81ce953f692c5e26b1df45f05ec":[2,0,0,34,8],
@@ -249,5 +247,7 @@ var NAVTREEINDEX2 =
 "classjuce_1_1CharPointer__UTF16.html#a4411719acb2804e27e70765259b1c754":[2,0,0,49,25],
 "classjuce_1_1CharPointer__UTF16.html#a4584148418ae6ea1945cf9a3fde7e5c2":[2,0,0,49,0],
 "classjuce_1_1CharPointer__UTF16.html#a4a2c94a5ff4d1020669b46c6a82ee205":[2,0,0,49,33],
-"classjuce_1_1CharPointer__UTF16.html#a601e1b32ff232b5ad3d711178bffff87":[2,0,0,49,30]
+"classjuce_1_1CharPointer__UTF16.html#a601e1b32ff232b5ad3d711178bffff87":[2,0,0,49,30],
+"classjuce_1_1CharPointer__UTF16.html#a6422c90ef9c521a55eba6f303e30e6a6":[2,0,0,49,36],
+"classjuce_1_1CharPointer__UTF16.html#a6ab602475c2534b5bb330532b9b19d7b":[2,0,0,49,9]
 };
