@@ -1,7 +1,5 @@
 var NAVTREEINDEX6 =
 {
-"classjuce_1_1MPEInstrument.html#a41a654610f46359202f9ecf3ee0cbbf8":[2,0,0,134,2],
-"classjuce_1_1MPEInstrument.html#a47a9a4d23d5cafc2b2dd8f724f71e1aa":[2,0,0,134,31],
 "classjuce_1_1MPEInstrument.html#a4d063e2629616fa2e23d8c025939dd0b":[2,0,0,134,21],
 "classjuce_1_1MPEInstrument.html#a4e037c9a2e3a11815d82043baa671fef":[2,0,0,134,23],
 "classjuce_1_1MPEInstrument.html#a4f24eeda81c8aebfa5f47db76fbe7323":[2,0,0,134,27],
@@ -249,5 +247,7 @@ var NAVTREEINDEX6 =
 "classjuce_1_1MidiBuffer.html#ac1fa694bab035f13855c0f4255f1e6c7":[2,0,0,117,4],
 "classjuce_1_1MidiBuffer.html#acc861b77fc4d3caf8c124790e93203a7":[2,0,0,117,2],
 "classjuce_1_1MidiBuffer.html#ad2dcf7d6edb7860b432d247f0efcccca":[2,0,0,117,8],
-"classjuce_1_1MidiBuffer.html#ad6c842cb85ef82b1c1f26379d21e3717":[2,0,0,117,7]
+"classjuce_1_1MidiBuffer.html#ad6c842cb85ef82b1c1f26379d21e3717":[2,0,0,117,7],
+"classjuce_1_1MidiBuffer.html#ade4e9d5b4ca396e94c03d3370972b77c":[2,0,0,117,9],
+"classjuce_1_1MidiBuffer.html#ae0467191657f0d393cb915ca88ba1944":[2,0,0,117,17]
 };
