@@ -1,7 +1,5 @@
 var NAVTREEINDEX7 =
 {
-"classjuce_1_1MidiBuffer.html#ade4e9d5b4ca396e94c03d3370972b77c":[2,0,0,117,9],
-"classjuce_1_1MidiBuffer.html#ae0467191657f0d393cb915ca88ba1944":[2,0,0,117,17],
 "classjuce_1_1MidiBuffer.html#af964706592abb799c9fef1c885cf5921":[2,0,0,117,3],
 "classjuce_1_1MidiBuffer_1_1Iterator.html":[2,0,0,117,0],
 "classjuce_1_1MidiBuffer_1_1Iterator.html#a2ee629505d48436c333f479795c6ca2b":[2,0,0,117,0,5],
@@ -249,5 +247,7 @@ var NAVTREEINDEX7 =
 "classjuce_1_1NamedPipe.html":[2,0,0,143],
 "classjuce_1_1NamedPipe.html#a184db9fcec3fe6e0e4d4d908f6dcf5c4":[2,0,0,143,8],
 "classjuce_1_1NamedPipe.html#a25ad354dbe15053d146e9bf8f4eb3427":[2,0,0,143,7],
-"classjuce_1_1NamedPipe.html#a4e8f9f455b98cc2c22c7b3bf9300953a":[2,0,0,143,4]
+"classjuce_1_1NamedPipe.html#a4e8f9f455b98cc2c22c7b3bf9300953a":[2,0,0,143,4],
+"classjuce_1_1NamedPipe.html#a9af215d2dd492dc72d7027e029bc74b3":[2,0,0,143,5],
+"classjuce_1_1NamedPipe.html#a9dcb83c89f29a449fba129c7ddab90ac":[2,0,0,143,3]
 };
